=======
Credits
=======

Development Lead
----------------

* Jasper Capel <jasper.capel@spilgames.com>
* Thijs de Zoete <thijs.dezoete@spilgames.com>

Contributors
------------

* Art van Scheppingen <art@spilgames.com> (idea and rough first implementation)
